<?php
/**
 * CT White functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package CT_White
 */

if ( ! defined( 'CT_WHITE_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'CT_WHITE_VERSION', '1.0.7' );
}

if ( ! function_exists( 'ct_white_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function ct_white_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on CT White, use a find and replace
		 * to change 'ct-white' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'ct-white', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'ct-white' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'ct_white_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);
		
		// Custom Image Sizes
		add_image_size('ct_white_thumb','500','400',true);
		

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 300,
				'width'       => 120,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'ct_white_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ct_white_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ct_white_content_width', 640 );
}
add_action( 'after_setup_theme', 'ct_white_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ct_white_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'ct-white' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'ct-white' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'ct-white' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add widgets here.', 'ct-white' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'ct-white' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add widgets here.', 'ct-white' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'ct-white' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Add widgets here.', 'ct-white' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'ct_white_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function ct_white_scripts() {
	wp_enqueue_style( 'ct-white-style', get_stylesheet_uri(), array(), CT_WHITE_VERSION );
	wp_style_add_data( 'ct-white-style', 'rtl', 'replace' );
	
	wp_enqueue_style('dashicons');
	
	wp_enqueue_style('ct-white-fonts', 'https://fonts.googleapis.com/css2?family=Source+Sans+Pro:wght@400;600;700&display=swap', array(), CT_WHITE_VERSION); 
	
	wp_enqueue_style('ct-white-main-css', get_template_directory_uri() . '/assets/css/main.css', array(), CT_WHITE_VERSION);
	
	wp_enqueue_script('ct-white-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array(), CT_WHITE_VERSION, true);

	wp_enqueue_script( 'ct-white-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), CT_WHITE_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ct_white_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 *	Footer Sidebar
 */
require get_template_directory() . '/inc/footer-sidebar.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 *	Walker for Navigation Menu
 */
require get_template_directory() . '/inc/walker.php';

/**
 *	Block Styles for the theme
 */
 require get_template_directory() . '/inc/block-styles.php';
 
 /**
  *	Include TGM Plugin Activation
  */
  require get_template_directory() . '/inc/tgmpa.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

